@@ -18,6 +18,7 @@
 
 from __future__ import with_statement
 
+import os
 from os import path as osp
 from shutil import rmtree
 import re
@@ -36,6 +37,8 @@ from cubes.vcsfile.testutils import init_vcsrepo
 from mercurial.__version__ import version as hgversion
 hg26 = (tuple(int(x) for x in hgversion.split('.')[:2]) >= (2, 6))
 
+os.environ['HGRCPATH'] = os.devnull
+
 def revnums(patch):
     return sorted(vc.revision for vc in patch.patch_revision)
 
@@ -71,10 +74,10 @@ class HgHelper(CubicWebTC):
         if self.verbose_hg:
             print ' '.join(args)
         else:
-            devnull = open('/dev/null', 'a')
+            devnull = open(os.devnull, 'a')
             kwargs['stdout'] = devnull
-            kwargs['stderr'] = devnull
-        check_call(['hg', '-R', self.tmprepo] + list(args), **kwargs)
+        check_call(['hg', '--config', 'ui.username=vcreview', '--config', 'extensions.evolve=',
+                    '--config', 'extensions.rebase=', '-R', self.tmprepo] + list(args), **kwargs)
 
     def append_to(self, path, content):
         """Add a new line to a file in the repo"""
