@@ -1,4 +1,4 @@
-# copyright 2011-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -52,12 +52,16 @@ class PatchReviewWorkflowTC(CubicWebTC):
 
     def setup_database(self):
         req = self.request()
+        # create users
         create_user = functools.partial(self.create_user, req)
         self.reviewer1 = create_user('Victor', ('users', 'reviewers'),
                                      email=u'victor@ratax.es')
         self.reviewer2 = create_user('Podular', ('users', 'reviewers'),
                                      email=u'podular@elephan.tz')
         self.committer = create_user('committer', ('users',))
+        self.commit()
+
+        # import revisions from repository
         with self.session.security_enabled(write=False):
             with self.session.deny_all_hooks_but('metadata'):
                 req.create_entity('Repository', type=u'mercurial',
@@ -67,14 +71,26 @@ class PatchReviewWorkflowTC(CubicWebTC):
                                   has_review=True)
                 self.commit()
                 init_vcsrepo(self.repo)
-                rset = req.execute('Patch P ORDERBY P DESC '
-                                   'WHERE P in_state S, '
-                                   '      S name "pending-review"')
-                self.patch1eid = rset[2][0]
-                self.patch2eid = rset[3][0]
-                self.commit()
-                self.task1eid = req.create_entity(
-                    'Task', reverse_has_activity=self.patch1eid, title=u'todo 1').eid
+
+        # ask review
+        rset = req.execute('Patch P ORDERBY P DESC '
+                           'WHERE P in_state S, '
+                           '      S name "in-progress"')
+        for patch in rset.entities():
+            patch.cw_adapt_to('IWorkflowable').fire_transition('ask review')
+        self.commit()
+
+        # record eids of patches pending review
+        rset = req.execute('Patch P ORDERBY P DESC '
+                           'WHERE P in_state S, '
+                           '      S name "pending-review"')
+        self.patch1eid = rset[2][0]
+        self.patch2eid = rset[3][0]
+        self.commit()
+
+        # create task
+        self.task1eid = req.create_entity(
+            'Task', reverse_has_activity=self.patch1eid, title=u'todo 1').eid
         self.commit()
 
     def test_wf(self):
